Pinned baseline

Repositorywesnoth/wesnoth
Observed branchmaster
Commit6ab3fc1af3e259515c9558564accd16c69800d62
Commit dateJuly 3, 2026
Audit access dateJuly 12, 2026
Bounded source files25

Earlier releases linked to moving master URLs. Release 1.0 records the exact commit used by the final closure audit and supplies commit-pinned links and SHA-256 hashes for every fetched dependency.

Snapshot contents

Repository pathBytesSHA-256Source
data/campaigns/The_Rise_Of_Wesnoth/units/Autumn_Shyde.cfg544f288991fb26d20b2…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Familiar.cfg2,350fdcdad5bd035e8a0…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Jevyan.cfg5,3821a23dbb1f33b23ac…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Jevyan_Cloaked.cfg3287ffe1d163fa6ed80…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Kalian.cfg239d7bba4b3dc8d6efe…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Commander.cfg2,848ba9aab14953d20b8…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Fighter.cfg1,416dacbfdafc26dbc76…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Lord.cfg2,70405cf0348ac2931b9…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Youth.cfg1,157114a9ba239b6254d…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Vampire_Lady.cfg2,381917752a29d0720fe…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Warrior_King.cfg813adab7d55bcd2e4d9…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Wesfolk_Lady.cfg6,29704f98772fa7abe3c…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Wesfolk_Leader.cfg6,388a30acc6257e5535e…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/units/Wesfolk_Outcast.cfg6,397d28de4db213d0e08…Pinned source
data/campaigns/The_Rise_Of_Wesnoth/utils/trow-abilities.cfg47174b082df34f4d533…Pinned source
data/core/macros/abilities.cfg15,44604e36aecefbe147c…Pinned source
data/core/macros/amla.cfg8549e07c80bb15f2ecb…Pinned source
data/core/macros/animation-utils.cfg43,2333dbe385afd94faa8…Pinned source
data/core/macros/animation-utils2.cfg8,5838b7b628f21410a80…Pinned source
data/core/macros/movetypes.cfg3,48978327cccd1376a51…Pinned source
data/core/macros/sound-utils.cfg14,309a4c4f93ecda8774f…Pinned source
data/core/macros/special-notes.cfg9,643fd74838fa2f85874…Pinned source
data/core/macros/weapon_specials.cfg9,27141b0f0c313a2ade0…Pinned source
data/core/units/elves/Champion.cfg2,92924a6751cce57c097…Pinned source
data/core/units/humans/Royal_Warrior.cfg1,979d638fe6753243614…Pinned source

Why only 25 files?

The full guide analyzes the complete campaign source surface. This smaller snapshot exists for one specific reproducible calculation: the custom-unit transitive dependency and inherited-audio closure. It includes:

  • all 14 campaign unit definitions,
  • the campaign’s ABILITY_DISTRACT definition,
  • the two inherited core unit types, and
  • the core macro files that define every symbol reached by those units.

Machine-readable provenance

The full manifest is bundled at assets/source-snapshot.json. The archive does not redistribute the upstream WML snapshot itself; it records paths, pinned links, byte counts, and hashes.

Pinned repository commit