Pinned baseline
| Repository | wesnoth/wesnoth |
|---|---|
| Observed branch | master |
| Commit | 6ab3fc1af3e259515c9558564accd16c69800d62 |
| Commit date | July 3, 2026 |
| Audit access date | July 12, 2026 |
| Bounded source files | 25 |
Earlier releases linked to moving master URLs. Release 1.0 records the exact commit used by the final closure audit and supplies commit-pinned links and SHA-256 hashes for every fetched dependency.
Snapshot contents
| Repository path | Bytes | SHA-256 | Source |
|---|---|---|---|
data/campaigns/The_Rise_Of_Wesnoth/units/Autumn_Shyde.cfg | 544 | f288991fb26d20b2… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Familiar.cfg | 2,350 | fdcdad5bd035e8a0… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Jevyan.cfg | 5,382 | 1a23dbb1f33b23ac… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Jevyan_Cloaked.cfg | 328 | 7ffe1d163fa6ed80… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Kalian.cfg | 239 | d7bba4b3dc8d6efe… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Commander.cfg | 2,848 | ba9aab14953d20b8… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Fighter.cfg | 1,416 | dacbfdafc26dbc76… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Lord.cfg | 2,704 | 05cf0348ac2931b9… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Noble_Youth.cfg | 1,157 | 114a9ba239b6254d… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Vampire_Lady.cfg | 2,381 | 917752a29d0720fe… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Warrior_King.cfg | 813 | adab7d55bcd2e4d9… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Wesfolk_Lady.cfg | 6,297 | 04f98772fa7abe3c… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Wesfolk_Leader.cfg | 6,388 | a30acc6257e5535e… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/units/Wesfolk_Outcast.cfg | 6,397 | d28de4db213d0e08… | Pinned source |
data/campaigns/The_Rise_Of_Wesnoth/utils/trow-abilities.cfg | 471 | 74b082df34f4d533… | Pinned source |
data/core/macros/abilities.cfg | 15,446 | 04e36aecefbe147c… | Pinned source |
data/core/macros/amla.cfg | 854 | 9e07c80bb15f2ecb… | Pinned source |
data/core/macros/animation-utils.cfg | 43,233 | 3dbe385afd94faa8… | Pinned source |
data/core/macros/animation-utils2.cfg | 8,583 | 8b7b628f21410a80… | Pinned source |
data/core/macros/movetypes.cfg | 3,489 | 78327cccd1376a51… | Pinned source |
data/core/macros/sound-utils.cfg | 14,309 | a4c4f93ecda8774f… | Pinned source |
data/core/macros/special-notes.cfg | 9,643 | fd74838fa2f85874… | Pinned source |
data/core/macros/weapon_specials.cfg | 9,271 | 41b0f0c313a2ade0… | Pinned source |
data/core/units/elves/Champion.cfg | 2,929 | 24a6751cce57c097… | Pinned source |
data/core/units/humans/Royal_Warrior.cfg | 1,979 | d638fe6753243614… | Pinned source |
Why only 25 files?
The full guide analyzes the complete campaign source surface. This smaller snapshot exists for one specific reproducible calculation: the custom-unit transitive dependency and inherited-audio closure. It includes:
- all 14 campaign unit definitions,
- the campaign’s
ABILITY_DISTRACTdefinition, - the two inherited core unit types, and
- the core macro files that define every symbol reached by those units.
Machine-readable provenance
The full manifest is bundled at assets/source-snapshot.json. The archive does not redistribute the upstream WML snapshot itself; it records paths, pinned links, byte counts, and hashes.